from __future__ import absolute_import
from solox.web import main
import fire as fire

if __name__ == '__main__':
    fire.Fire(main)
